#ifndef PIXELWINDOW_H
#define PIXELWINDOW_H

#include <QMainWindow>
#include <QMouseEvent>

namespace Ui {
    class pixelWindow;
}

class pixelWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit pixelWindow(QWidget *parent = 0);
    ~pixelWindow();

private:
    Ui::pixelWindow *ui;
        QPoint discposition;

protected:
    void paintEvent();
    void mouseMoveEvent(QMouseEvent *event);
    //void mousePressEvent(QMouseEvent *event);




private slots:
    void on_pushButton_clicked();

};

#endif // PIXELWINDOW_H
